# (c) 2024 Christophe Gueneau
from time import sleep_ms
 
class Md22(object):
    """Classe définissant le driver moteur MD22"""
    def __init__(self, i2c, num_mode):
        self._i2c = i2c
        self._adr_i2c = 0x58                 #adresse I2C par défaut
        sleep_ms(10)
        self._ecriture_registre(self._adr_i2c, 0x00, num_mode)
        sleep_ms(10)
    
    def _ecriture_registre(self, adresse_i2c, adresse_registre, val):
        buf = bytes((adresse_registre, val))
        self._i2c.writeto(adresse_i2c, buf)   
   
    def scan_i2c_adresse(self):
        adresses = self._i2c.scan()
        if len(adresses) == 0:
            print("Pas d'adresses trouvees")
        else:
            print(len(adresses), "adresses I2C trouves")
            print("Decimal | Hexadecimal")
            for adresses in adresses:
                print("  ", adresses, "  |  ", hex(adresses))
   
    def vit_dir(self, vit, dir):
        self._ecriture_registre(self._adr_i2c, 0x01, vit)
        self._ecriture_registre(self._adr_i2c, 0x02, dir)
        
    def vit_m1(self, vit):
        self._ecriture_registre(self._adr_i2c, 0x01, vit)

    def vit_m2(self, vit):
        self._ecriture_registre(self._adr_i2c, 0x02, vit)

if __name__ == '__main__':
    from time import sleep_ms
    from machine import Pin, I2C
    
    # Crée un objet I2C
    i2c0 = I2C(0, scl=Pin(9), sda=Pin(8), freq=400000)    # I2C0 utilisé

    # Crée un objet Md22 avec le mode 2
    md = Md22(i2c0, 2)
    
    md.scan_i2c_adresse()   # Scanne les adresses I2C
    
    # Commandes mode 2
    md.vit_dir(160, 128)    # avant tout droit
    sleep_ms(4000) 
    md.vit_dir(160, 255)    # avant tourne à gauche
    sleep_ms(4000)
    md.vit_dir(128, 128)    # arrêt

    
    
    